import json;
import sys;
import string;

if len(sys.argv)!=2:
	print("Usage: python hack/list-swagger-objects.py <swagger-spec-location>")
	sys.exit(1)

swagger_spec_location=sys.argv[1]

with open(swagger_spec_location, 'r') as source:
	for model in json.load(source)["models"]:
		print(string.lower(model))


#!/usr/bin/env python

# Copyright 2015 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer

PORT_NUMBER = 8000

# This class will handles any incoming request.
class HTTPHandler(BaseHTTPRequestHandler):
  # Handler for the GET requests
  def do_GET(self):
    self.send_response(200)
    self.send_header('Content-type','text/html')
    self.end_headers()
    self.wfile.write("Hello World!")

try:
  # Create a web server and define the handler to manage the incoming request.
  server = HTTPServer(('', PORT_NUMBER), HTTPHandler)
  print 'Started httpserver on port ' , PORT_NUMBER
  server.serve_forever()
except KeyboardInterrupt:
  print '^C received, shutting down the web server'
  server.socket.close()



"""
Code for building Origin
"""
import json

from tito.common import get_latest_commit, run_command
from tito.builder import Builder

from ..common import inject_os_git_vars

class OriginBuilder(Builder):
    """
    builder which defines 'commit' as the git hash prior to building

    Used For:
        - Packages that want to know the commit in all situations
    """
    def _get_tag_for_version(self, version):
        return "v{}".format(version)

    def _get_rpmbuild_dir_options(self):
        git_hash = get_latest_commit()
        cmd = 'source ./hack/lib/init.sh; os::build::ldflags'
        ldflags = run_command("bash -c '{0}'".format(cmd))

        return ('--define "_topdir %s" --define "_sourcedir %s" --define "_builddir %s" '
                '--define "_srcrpmdir %s" --define "_rpmdir %s" --define "ldflags %s" '
                '--define "commit %s" ' % (
                    self.rpmbuild_dir,
                    self.rpmbuild_sourcedir, self.rpmbuild_builddir,
                    self.rpmbuild_basedir, self.rpmbuild_basedir,
                    ldflags, git_hash))

    def _setup_test_specfile(self):
        if self.test and not self.ran_setup_test_specfile:
            super(OriginBuilder, self)._setup_test_specfile()

            inject_os_git_vars(self.spec_file)
            self._inject_bundled_deps()

    def _inject_bundled_deps(self):
            # Add bundled deps for Fedora Guidelines as per:
            # https://fedoraproject.org/wiki/Packaging:Guidelines#Bundling_and_Duplication_of_system_libraries
            provides_list = []
            with open("./Godeps/Godeps.json") as godeps:
                depdict = json.load(godeps)
                for bdep in [
                    (dep[u'ImportPath'], dep[u'Rev'])
                    for dep in depdict[u'Deps']
                ]:
                    provides_list.append(
                        "Provides: bundled(golang({0})) = {1}".format(
                            bdep[0],
                            bdep[1]
                        )
                    )

            # Handle this in python because we have hit the upper bounds of line
            # count for what we can pass into sed via subprocess because there
            # are so many bundled libraries.
            with open(self.spec_file, 'r') as spec_file_f:
                spec_file_lines = spec_file_f.readlines()
            with open(self.spec_file, 'w') as spec_file_f:
                for line in spec_file_lines:
                    if '### AUTO-BUNDLED-GEN-ENTRY-POINT' in line:
                            spec_file_f.write(
                                '\n'.join(
                                    [provides.replace('"', '').replace("'", '')
                                     for provides in provides_list]
                                )
                            )
                    else:
                        spec_file_f.write(line)

# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:textwidth=0:



"""
Code for tagging Origin packages
"""
from tito.tagger import VersionTagger

from ..common import inject_os_git_vars, update_global_hash

class OriginTagger(VersionTagger):
    """
    Origin custom tagger. This tagger has several deviations from the normal
    tito tagger.

    ** Rather than versions being tagged %{name}-%{version}-%{release} they're
    tagged as v%{version} in order to preserve compatibility with origin build
    processes. This means you really should not attempt to use the release field
    for anything useful, it should probably always remain zero.

    ** RPM specfile global commit is updated with the git hash, this may be
    relevant and popular with other golang projects, so TODO: submit to tito
    upstream.

    Requires that your commit global is written on one single line like this:

    %global commit 460abe2a3abe0fa22ac96c551fe71c0fc36f7475

    ** RPM specfile global ldflags is updated with os::build::ldflags as generated
    by importing hack/common.sh this absolutely depends on the non standard
    version tagging outlined above. This is 100% openshift specific

    Requires that your ldflags global is written on one single line like this:
    %global ldflags -X foo -X bar

    Used For:
    - Origin, probably not much else
    """

    def _tag_release(self):
        update_global_hash(self.spec_file)
        inject_os_git_vars(self.spec_file)
        super(OriginTagger, self)._tag_release()

    def _get_tag_for_version(self, version):
        return "v{}".format(version)
# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:textwidth=0:



#!/usr/bin/env python

# Copyright 2015 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argparse
import requests
import socket

from urlparse import urlparse


def CheckServiceAddress(address):
  hostname = urlparse(address).hostname
  service_address = socket.gethostbyname(hostname)
  print service_address


def GetServerResponse(address):
  print 'Send request to:', address
  response = requests.get(address)
  print response
  print response.content


def Main():
  parser = argparse.ArgumentParser()
  parser.add_argument('address')
  args = parser.parse_args()
  CheckServiceAddress(args.address)
  GetServerResponse(args.address)


if __name__ == "__main__":
  Main()
